@@ -275,21 +275,22 @@ def fetch_plos_images(article_doi, output_dir, document):
                     'pmed': 'http://www.plosmedicine.org/article/{0}',
                     'pbio': 'http://www.plosbiology.org/article/{0}',
                     'pone': 'http://www.plosone.org/article/{0}',
-                    'pctr': 'http://clinicaltrials.ploshubs.org/article/{0]}'}
+                    'pctr': 'http://clinicaltrials.ploshubs.org/article/{0}'}
 
     #Identify subjournal name for base URl
     subjournal_name = article_doi.split('.')[1]
     base_url = journal_urls[subjournal_name]
 
     #Acquire <graphic> and <inline-graphic> xml elements
-    graphics = document.root_tag.getElementsByTagName('graphic')
-    graphics += document.root_tag.getElementsByTagName('inline-graphic')
+    graphics = document.document.getroot().findall('.//graphic')
+    graphics += document.document.getroot().findall('.//inline-graphic')
 
     #Begin to download
     print('Downloading images, this may take some time...')
     for graphic in graphics:
-        xlink_href = graphic.getAttribute('xlink:href')
-        if xlink_href[-4] == 'e':  # Equations are handled differently
+        nsmap = document.document.getroot().nsmap
+        xlink_href = graphic.attrib['{'+nsmap['xlink']+'}'+'href']
+        if xlink_href[-4] == 'e' or xlink_href[-3] == 'e':  # Equations are handled differently
             resource = 'fetchObject.action?uri=' + xlink_href + '&representation=PNG'
         else:
             resource = xlink_href + '/largerimage'
@@ -305,7 +306,7 @@ def fetch_plos_images(article_doi, output_dir, document):
                     return False  # Happened twice, give up
             else:
                 log.error('urllib.error.HTTPError {0}'.format(e.code))
-            return False
+                return False
         else:
             img_name = xlink_href.split('.')[-1] + '.png'
             img_path = os.path.join(output_dir, img_name)
